@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "grantleetheme.h"
@@ -47,7 +35,7 @@ ThemePrivate::ThemePrivate(const ThemePrivate &other)
     , description(other.description)
     , name(other.name)
     , dirName(other.dirName)
-    , absolutePath(other.absolutePath)
+    , absolutePaths(other.absolutePaths)
     , author(other.author)
     , email(other.email)
     , loader(other.loader)
@@ -66,11 +54,16 @@ void ThemePrivate::setupEngine()
 void ThemePrivate::setupLoader()
 {
     // Get the parent dir with themes, we set the theme directory separately
-    QDir dir(absolutePath);
-    dir.cdUp();
+
+    QStringList templatePaths;
+    for (const QString &absolutePath : qAsConst(absolutePaths)) {
+        QDir dir(absolutePath);
+        dir.cdUp();
+        templatePaths << dir.absolutePath();
+    }
 
     loader = QSharedPointer<GrantleeTheme::QtResourceTemplateLoader>::create();
-    loader->setTemplateDirs({ dir.absolutePath() });
+    loader->setTemplateDirs(templatePaths);
     loader->setTheme(dirName);
 
     if (!sEngine) {
@@ -122,7 +115,7 @@ Theme::Theme(const QString &themePath, const QString &dirName, const QString &de
     KConfigGroup group(&config, QStringLiteral("Desktop Entry"));
     if (group.isValid()) {
         d->dirName = dirName;
-        d->absolutePath = themePath;
+        d->absolutePaths.append(themePath);
         d->name = group.readEntry("Name", QString());
         d->description = group.readEntry("Description", QString());
         d->themeFileName = group.readEntry("FileName", QString());
@@ -141,7 +134,7 @@ Theme::~Theme()
 
 bool Theme::operator==(const Theme &other) const
 {
-    return isValid() && other.isValid() && d->absolutePath == other.absolutePath();
+    return isValid() && other.isValid() && d->absolutePaths == other.d->absolutePaths;
 }
 
 Theme &Theme::operator=(const Theme &other)
@@ -185,7 +178,10 @@ QString Theme::dirName() const
 
 QString Theme::absolutePath() const
 {
-    return d->absolutePath;
+    if (!d->absolutePaths.isEmpty()) {
+        return d->absolutePaths.at(0); // ####
+    }
+    return {};
 }
 
 QString Theme::author() const
@@ -198,6 +194,11 @@ QString Theme::authorEmail() const
     return d->email;
 }
 
+void Theme::addThemePath(const QString &path)
+{
+    d->absolutePaths.append(path);
+}
+
 QString Theme::render(const QString &templateName, const QVariantHash &data, const QByteArray &applicationDomain)
 {
     if (!d->loader) {
@@ -206,7 +207,7 @@ QString Theme::render(const QString &templateName, const QVariantHash &data, con
     Q_ASSERT(d->loader);
 
     if (!d->loader->canLoadTemplate(templateName)) {
-        qCWarning(GRANTLEETHEME_LOG) << "Cannot load template" << templateName << ", please check your installation";
+        qCWarning(GRANTLEETHEME_LOG) << "Cannot load template" << templateName << ", please check your installation. Tried in these dirs:" << d->loader->templateDirs();
         return QString();
     }
 
